@@ -13,10 +13,10 @@ use Smart::Args;
 
 use App::Koyomi::Semaphore;
 
-use version; our $VERSION = 'v0.2.0';
+use version; our $VERSION = 'v0.3.0';
 
 our @JOB_FIELDS  = qw/id user command memo created_on updated_at/;
-our @TIME_FIELDS = qw/job_id year month day hour minute weekday created_on updated_at/;
+our @TIME_FIELDS = qw/id job_id year month day hour minute weekday created_on updated_at/;
 
 {
     no strict 'refs';
@@ -62,9 +62,9 @@ sub proceed {
         return;
     }
 
-    my $user = $self->user || $ENV{USER} || $ENV{LOGNAME} || getlogin() || getpwuid($<) || '<Undefined>';
-    infof(q/%s USER=%s COMMAND="%s"/, $header, $user, $self->command);
-    my ($ok, $err, undef, $stdout, $stderr) = IPC::Cmd::run(command => $self->command);
+    my $user = $self->user || $self->_proc_user;
+    infof(q/%s USER=%s COMMAND="%s"/, $header, $user, $self->command_to_exec);
+    my ($ok, $err, undef, $stdout, $stderr) = IPC::Cmd::run(command => $self->command_to_exec);
     if ($ok) {
         infof(q/%s Succeeded./, $header);
         if (scalar(@$stdout)) {
@@ -89,6 +89,20 @@ sub proceed {
     }
 }
 
+sub command_to_exec {
+    my $self = shift;
+    return ($self->user && $self->user ne $self->_proc_user)
+        ? sprintf('sudo -u %s %s', $self->user, $self->command)
+        : $self->command;
+}
+
+sub _proc_user {
+    my $self = shift;
+    return
+        $ENV{USER} || $ENV{LOGNAME} || getlogin() || getpwuid($<)
+            || croakf(q/Can't get user of process! id=%d/, $self->id);
+}
+
 sub _get_lock {
     args(
         my $self,
